@@ -1,7 +1,5 @@
 hyperDistancePathIndex <- function(g, dist=NULL, wien=NULL){
-  require("combinat")
-  require("graph")
-  if(class(g)[1]!="graphNEL"){
+   if(class(g)[1]!="graphNEL"){
     stop("'g' must be a 'graphNEL' object")
   }
    stopifnot(.validateGraph(g))
