@@ -1,5 +1,4 @@
 infoTheoreticGCM <- function(g, dist=NULL, coeff="lin", infofunct="sphere", lambda=1000, custCoeff=NULL, alpha=0.5, prec=53, flag.alpha=FALSE){
-  require("graph")
   if (prec > 53)
     require("Rmpfr")
 
@@ -104,7 +103,11 @@ infoTheoreticGCM <- function(g, dist=NULL, coeff="lin", infofunct="sphere", lamb
     as.double(ci), as.integer(length(ci)),
     double(size))[[6]]
 
-  fvi <- alpha ^ if (prec > 53) mpfr(expts, prec) else expts
+  fvi <- alpha ^ if (prec > 53) {
+    Rmpfr::mpfr(expts, prec)}
+  else {
+    expts
+  }
   names(fvi) <- nodes(g)
 
   fvi
