@@ -12,13 +12,14 @@ infoTheoreticLabeledV1 <- function(g, dist=NULL, coeff="lin", custCoeff=NULL, co
   # if there is no coefficient matrix, create one from coeff/custCoeff
   # and the masses of the atoms in the graph
   if (is.null(coeffMatrix)) {
+    ##data(sysdata, envir=environment())
     diam <- max(dist)
     ci <- .infoTheoreticCoeff(coeff, custCoeff, diam)
     coeffMatrix <- matrix(0, nrow=diam, ncol=length(uniq.labels))
     colnames(coeffMatrix) <- uniq.labels
-    uranium <- round(chemicalElements[92, "mass"])
+    uranium <- round(.chemicalElements()[92, "mass"])
     relmasses <- sapply(uniq.labels, function(label) {
-      absmass <- chemicalElements[chemicalElements$symbol == label, "mass"]
+      absmass <- .chemicalElements()[.chemicalElements()$symbol == label, "mass"]
       round(absmass) / uranium
     })
 
